==> suir-component-mapper-3.12.0.tgz: package/esm/select/select.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import CommonSelect from '@data-driven-forms/common/select';
import parseInternalValue from '@data-driven-forms/common/select/parse-internal-value';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import { meta, input } from '@data-driven-forms/common/prop-types-templates';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import Dropdown from "semantic-ui-react/dist/es/modules/Dropdown/Dropdown.js";
import FormField from '../form-field/form-field';

var SuirSelect = function SuirSelect(_ref) {
  var _onChange = _ref.onChange,
      value = _ref.value,
      meta = _ref.meta,
      helperText = _ref.helperText,
      validateOnMount = _ref.validateOnMount,
      isReadOnly = _ref.isReadOnly,
      isDisabled = _ref.isDisabled,
      isClearable = _ref.isClearable,
      isSearchable = _ref.isSearchable,
      options = _ref.options,
      label = _ref.label,
      isMulti = _ref.isMulti,
      isRequired = _ref.isRequired,
      classNamePrefix = _ref.classNamePrefix,
      onInputChange = _ref.onInputChange,
      isFetching = _ref.isFetching,
      noOptionsMessage = _ref.noOptionsMessage,
      hideSelectedOptions = _ref.hideSelectedOptions,
      closeMenuOnSelect = _ref.closeMenuOnSelect,
      FormFieldGridProps = _ref.FormFieldGridProps,
      HelpertextProps = _ref.HelpertextProps,
      rest = _objectWithoutProperties(_ref, ["onChange", "value", "meta", "helperText", "validateOnMount", "isReadOnly", "isDisabled", "isClearable", "isSearchable", "options", "label", "isMulti", "isRequired", "classNamePrefix", "onInputChange", "isFetching", "noOptionsMessage", "hideSelectedOptions", "closeMenuOnSelect", "FormFieldGridProps", "HelpertextProps"]);

  var invalid = validationError(meta, validateOnMount);
  var internalValue = parseInternalValue(value, isMulti);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelpertextProps: HelpertextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    disabled: isDisabled,
    readOnly: isReadOnly,
    required: isRequired,
    clearable: isClearable,
    search: isSearchable,
    loading: isFetching,
    noResultsMessage: isFetching ? 'Loading' : noOptionsMessage(),
    onSearchChange: function onSearchChange(_ref2) {
      var value = _ref2.target.value;
      return onInputChange(value);
    },
    options: options.map(function (_ref3) {
      var label = _ref3.label,
          value = _ref3.value,
          rest = _objectWithoutProperties(_ref3, ["label", "value"]);

      return _objectSpread({
        key: value,
        text: label,
        value: value
      }, rest);
    }),
    onChange: function onChange(_event, _ref4) {
      var value = _ref4.value;

      if (isMulti) {
        return _onChange(Array.isArray(value) && value.map(function (value) {
          return {
            value: value
          };
        }));
      }

      return _onChange(value && {
        value: value
      });
    },
    selection: true,
    fluid: true,
    multiple: isMulti,
    label: label,
    error: invalid && {
      content: meta.error || meta.submitError
    },
    control: Dropdown,
    value: internalValue
  }, rest)));
};

SuirSelect.propTypes = {
  input: input,
  meta: meta,
  placeholder: PropTypes.node,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isSearchable: PropTypes.bool,
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.any.isRequired,
    label: PropTypes.node.isRequired
  })),
  description: PropTypes.node,
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  onChange: PropTypes.func.isRequired,
  value: PropTypes.any,
  isMulti: PropTypes.bool,
  isClearable: PropTypes.bool,
  noOptionsMessage: PropTypes.func,
  isRequired: PropTypes.bool,
  classNamePrefix: PropTypes.string,
  onInputChange: PropTypes.func,
  isFetching: PropTypes.bool,
  hideSelectedOptions: PropTypes.bool,
  closeMenuOnSelect: PropTypes.bool,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelpertextProps: PropTypes.object
};
SuirSelect.defaultProps = {
  placeholder: 'Please choose',
  noOptionsMessage: 'No option found',
  options: [],
  FormFieldGridProps: {},
  HelpertextProps: {}
};

var Select = function Select(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      formProps = _objectWithoutProperties(_useFieldApi, ["input"]);

  return /*#__PURE__*/React.createElement(CommonSelect, _extends({
    simpleValue: true
  }, input, formProps, {
    SelectComponent: SuirSelect
  }));
};

export default Select;
export var InternalSelect = SuirSelect;

==> suir-component-mapper-3.15.0.tgz: package/esm/select/select.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["onChange", "value", "meta", "helperText", "validateOnMount", "isReadOnly", "isDisabled", "isClearable", "isSearchable", "options", "label", "isMulti", "isRequired", "classNamePrefix", "onInputChange", "isFetching", "noOptionsMessage", "hideSelectedOptions", "closeMenuOnSelect", "FormFieldGridProps", "HelpertextProps"],
    _excluded2 = ["label", "value"],
    _excluded3 = ["input"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import CommonSelect from '@data-driven-forms/common/select';
import parseInternalValue from '@data-driven-forms/common/select/parse-internal-value';
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
import { meta, input } from '@data-driven-forms/common/prop-types-templates';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import Dropdown from "semantic-ui-react/dist/es/modules/Dropdown/Dropdown.js";
import FormField from '../form-field/form-field';

var SuirSelect = function SuirSelect(_ref) {
  var _onChange = _ref.onChange,
      value = _ref.value,
      meta = _ref.meta,
      helperText = _ref.helperText,
      validateOnMount = _ref.validateOnMount,
      isReadOnly = _ref.isReadOnly,
      isDisabled = _ref.isDisabled,
      isClearable = _ref.isClearable,
      isSearchable = _ref.isSearchable,
      options = _ref.options,
      label = _ref.label,
      isMulti = _ref.isMulti,
      isRequired = _ref.isRequired,
      classNamePrefix = _ref.classNamePrefix,
      onInputChange = _ref.onInputChange,
      isFetching = _ref.isFetching,
      noOptionsMessage = _ref.noOptionsMessage,
      hideSelectedOptions = _ref.hideSelectedOptions,
      closeMenuOnSelect = _ref.closeMenuOnSelect,
      FormFieldGridProps = _ref.FormFieldGridProps,
      HelpertextProps = _ref.HelpertextProps,
      rest = _objectWithoutProperties(_ref, _excluded);

  var invalid = validationError(meta, validateOnMount);
  var internalValue = parseInternalValue(value, isMulti);
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelpertextProps: HelpertextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    disabled: isDisabled,
    readOnly: isReadOnly,
    required: isRequired,
    clearable: isClearable,
    search: isSearchable,
    loading: isFetching,
    noResultsMessage: isFetching ? 'Loading' : noOptionsMessage(),
    onSearchChange: function onSearchChange(_ref2) {
      var value = _ref2.target.value;
      return onInputChange(value);
    },
    options: options.map(function (_ref3) {
      var label = _ref3.label,
          value = _ref3.value,
          rest = _objectWithoutProperties(_ref3, _excluded2);

      return _objectSpread({
        key: value,
        text: label,
        value: value
      }, rest);
    }),
    onChange: function onChange(_event, _ref4) {
      var value = _ref4.value;

      if (isMulti) {
        return _onChange(Array.isArray(value) && value.map(function (value) {
          return {
            value: value
          };
        }));
      }

      return _onChange(value && {
        value: value
      });
    },
    selection: true,
    fluid: true,
    multiple: isMulti,
    label: label,
    error: invalid && {
      content: meta.error || meta.submitError
    },
    control: Dropdown,
    value: internalValue
  }, rest)));
};

SuirSelect.propTypes = {
  input: input,
  meta: meta,
  placeholder: PropTypes.node,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  isSearchable: PropTypes.bool,
  options: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.any.isRequired,
    label: PropTypes.node.isRequired
  })),
  description: PropTypes.node,
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  onChange: PropTypes.func.isRequired,
  value: PropTypes.any,
  isMulti: PropTypes.bool,
  isClearable: PropTypes.bool,
  noOptionsMessage: PropTypes.func,
  isRequired: PropTypes.bool,
  classNamePrefix: PropTypes.string,
  onInputChange: PropTypes.func,
  isFetching: PropTypes.bool,
  hideSelectedOptions: PropTypes.bool,
  closeMenuOnSelect: PropTypes.bool,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelpertextProps: PropTypes.object
};
SuirSelect.defaultProps = {
  placeholder: 'Please choose',
  noOptionsMessage: 'No option found',
  options: [],
  FormFieldGridProps: {},
  HelpertextProps: {}
};

var Select = function Select(props) {
  var _useFieldApi = useFieldApi(props),
      input = _useFieldApi.input,
      formProps = _objectWithoutProperties(_useFieldApi, _excluded3);

  return /*#__PURE__*/React.createElement(CommonSelect, _extends({
    simpleValue: true
  }, input, formProps, {
    SelectComponent: SuirSelect
  }));
};

export default Select;
export var InternalSelect = SuirSelect;
